assistants/wrap library
Classes
- Wrap
- Coordinates registration of wrap-based code assists for Nocterm components.
- WrapCenter
- A correction processor that can make one of the possible changes computed by the Wrap producer.
- WrapColumn
- A correction processor that can make one of the possible changes computed by the Wrap producer.
- WrapContainer
- A correction processor that can make one of the possible changes computed by the Wrap producer.
- WrapExpanded
- A correction processor that can make one of the possible changes computed by the Wrap producer.
- WrapFlexible
- A correction processor that can make one of the possible changes computed by the Wrap producer.
- WrapGeneric
- A correction processor that can make one of the possible changes computed by the Wrap producer.
- WrapPadding
- A correction processor that can make one of the possible changes computed by the Wrap producer.
- WrapRow
- A correction processor that can make one of the possible changes computed by the Wrap producer.
- WrapSizedBox
- A correction processor that can make one of the possible changes computed by the Wrap producer.