The priorities associated with various groups of assists.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- default_ → const int
- noctermMove → const int
- noctermRemove → const int
- noctermSwap → const int
- noctermWrapGeneral → const int
- noctermWrapSpecific → const int
- priority → const int