MethodInvocationExtension extension

on
  • MethodInvocation

Properties

isCastMethodInvocation → bool

Available on MethodInvocation, provided by the MethodInvocationExtension extension

Returns whether this expression is an invocation of the method cast from either Iterable, List, Map, or Set`.
no setter
isToListMethodInvocation → bool

Available on MethodInvocation, provided by the MethodInvocationExtension extension

Returns whether this expression is an invocation of the method toList from Iterable.
no setter
isToSetMethodInvocation → bool

Available on MethodInvocation, provided by the MethodInvocationExtension extension

Returns whether this expression is an invocation of the method toSet from Iterable.
no setter