ClassElementExtensions extension

on
  • ClassElement

Properties

isDartCoreIterable → bool

Available on ClassElement, provided by the ClassElementExtensions extension

Return true if this element represents the class Iterable from dart:core.
no setter
isDartCoreList → bool

Available on ClassElement, provided by the ClassElementExtensions extension

Return true if this element represents the class List from dart:core.
no setter
isDartCoreMap → bool

Available on ClassElement, provided by the ClassElementExtensions extension

Return true if this element represents the class Map from dart:core.
no setter
isDartCoreSet → bool

Available on ClassElement, provided by the ClassElementExtensions extension

Return true if this element represents the class Set from dart:core.
no setter