MethodElementExtensions extension

on
  • MethodElement

Properties

isCastMethod → bool

Available on MethodElement, provided by the MethodElementExtensions extension

Return true if this element represents the method cast from either Iterable, List, Map, or Set.
no setter
isToListMethod → bool

Available on MethodElement, provided by the MethodElementExtensions extension

Return true if this element represents the method toList from Iterable.
no setter
isToSetMethod → bool

Available on MethodElement, provided by the MethodElementExtensions extension

Return true if this element represents the method toSet from Iterable.
no setter