LogLevel enum

Log level severity.

Inheritance
Available extensions

Values

debug → const LogLevel

Debug level - most verbose.

const LogLevel(0, 'DEBUG')
info → const LogLevel

Info level - general information.

const LogLevel(1, 'INFO')
warning → const LogLevel

Warning level - potential issues.

const LogLevel(2, 'WARN')
error → const LogLevel

Error level - significant errors.

const LogLevel(3, 'ERROR')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
label → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.